@@ -1,7 +1,7 @@
-from typing import Union
-from enum import Enum
-from typing import List
 from dataclasses import dataclass
+from typing import Union
+from typing import List
+from enum import Enum
 
 
 class ActivationsEnum(Enum):
@@ -196,6 +196,7 @@ class NodeType(Enum):
     Nadam = "Nadam"
     RMSprop = "RMSprop"
     SGD = "SGD"
+    OnnxAbs = "OnnxAbs"
     OnnxErf = "OnnxErf"
     OnnxHardSigmoid = "OnnxHardSigmoid"
     OnnxReduceMean = "OnnxReduceMean"
@@ -203,7 +204,6 @@ class NodeType(Enum):
     Dataset = "Dataset"
     RepresentationBlock = "RepresentationBlock"
     GroundTruth = "GroundTruth"
-    CustomLayer = "CustomLayer"
     CustomLoss = "CustomLoss"
     Visualizer = "Visualizer"
     Lambda = "Lambda"
@@ -1645,6 +1645,11 @@ class SGD:
     type: NodeType
 
 
+@dataclass
+class OnnxAbs:
+    type: NodeType
+
+
 @dataclass
 class OnnxErf:
     type: NodeType
@@ -1684,11 +1689,6 @@ class GroundTruth:
     type: NodeType
 
 
-@dataclass
-class CustomLayer:
-    type: NodeType
-
-
 @dataclass
 class CustomLoss:
     type: NodeType
@@ -1760,6 +1760,6 @@ class NodeDataTypes:
                  ZeroPadding1D, ZeroPadding2D, ZeroPadding3D, BinaryCrossentropy, BinaryFocalCrossentropy, 
                  CategoricalCrossentropy, CategoricalHinge, CosineSimilarity, Hinge, Huber, KLDivergence, LogCosh, 
                  MeanAbsoluteError, MeanAbsolutePercentageError, MeanSquaredError, MeanSquaredLogarithmicError, Poisson, 
-                 SquaredHinge, Adadelta, Adagrad, Adam, Adamax, Ftrl, Nadam, RMSprop, SGD, OnnxErf, OnnxHardSigmoid, 
-                 OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLayer, CustomLoss, 
+                 SquaredHinge, Adadelta, Adagrad, Adam, Adamax, Ftrl, Nadam, RMSprop, SGD, OnnxAbs, OnnxErf, 
+                 OnnxHardSigmoid, OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLoss, 
                  Visualizer, Lambda, TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, FixedDropout]
